@@ -996,17 +996,60 @@ sub upsurl {
     return sprintf( "http://search.cpan.org/dist/%s/", $self->perlname );
 }
 
+
+my $ACTUAL_NAME_RE = '\pL[\s\pL\-\'\.]*\pL';
+
+# See http://www.faqs.org/rfcs/rfc2822.html
+# Section 3.4.1
+use Email::Address;
+my $EMAIL_RE = $Email::Address::addr_spec;
+
+my $EMAIL_CHANGES_RE = qr{
+    ^                           # beginining of line
+    \s+\*\s                     # item marker
+    Email\schange:\s            # email change token
+    ($ACTUAL_NAME_RE)           # actual name
+    \s+->\s+                    # gap between name and email
+    ($EMAIL_RE)                 # email address
+    $                           # end of line
+}xms;
+
+my $PERSON_PARSE_RE = qr{
+    \A                          # beginining of string
+    ($ACTUAL_NAME_RE)           # actual name
+    \s                          # gap
+    \<$EMAIL_RE\>               # logged email
+    \z                          # end of string
+}xms;
+
+# This is what needs fixing.
 sub copyright_from_changelog {
     my ( $self, $firstmaint, $firstyear ) = @_;
     my %maintainers = ();
     @{ $maintainers{$firstmaint} } = ($firstyear);
     my $chglog = Parse::DebianChangelog->init(
         { infile => $self->debian_file('changelog') } );
+    my %email_changes = ();
     foreach ( $chglog->data() ) {
         my $person      = $_->Maintainer;
         my $date        = $_->Date;
         my @date_pieces = split( " ", $date );
         my $year        = $date_pieces[3];
+        if (my %changes = ($_->Changes =~ m/$EMAIL_CHANGES_RE/xmsg)) {
+            # This way round since we are going backward in time thru changelog
+            foreach my $p (keys %changes) {
+                $changes{$p} =~ s{[\s\n]+$}{}xms;
+            }
+            %email_changes = (
+                %changes,
+                %email_changes
+            );
+        }
+        if (my ($name) = ($person =~ $PERSON_PARSE_RE)) {
+            if (exists $email_changes{$name}) {
+                $person = "$name <$email_changes{$name}>";
+            }
+        }
         if ( defined( $maintainers{$person} ) ) {
             push @{ $maintainers{$person} }, $year;
             @{ $maintainers{$person} } = sort( @{ $maintainers{$person} } );
@@ -1406,7 +1449,7 @@ sub _file_w {
 
 =item Copyright (C) 2008, Roberto C. Sanchez <roberto@connexer.com>
 
-=item Copyright (C) 2009-2010, Salvatore Bonaccorso <salvatore.bonaccorso@gmail.com>
+=item Copyright (C) 2009-2010, Salvatore Bonaccorso <carnil@debian.org>
 
 =back
 
